@@ -7,6 +7,24 @@
 #include <glib.h>
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
+/* Work around bugs in PyGILState api fixed in 2.4.0a4 */
+#if PY_VERSION_HEX < 0x020400A4
+#define PYGIL_API_IS_BUGGY TRUE
+#else
+#define PYGIL_API_IS_BUGGY FALSE
+#endif
+
+  /* PyGClosure is a _private_ structure */
+typedef struct _PyGClosure PyGClosure;
+struct _PyGClosure {
+    GClosure closure;
+    PyObject *callback;
+    PyObject *extra_args; /* tuple of extra args to pass to callback */
+    PyObject *swap_data; /* other object for gtk_signal_connect_object */
+};
+
 typedef struct {
     PyObject_HEAD
     GObject *obj;
@@ -121,20 +139,22 @@ struct _PyGObject_Functions {
 					const GParamSpec* pspec);
     PyTypeObject *enum_type;
     PyObject *(*enum_add)(PyObject *module,
-			  const char *typename,
+			  const char *typename_,
 			  const char *strip_prefix,
 			  GType gtype);
     PyObject* (*enum_from_gtype)(GType gtype, int value);
     
     PyTypeObject *flags_type;
     PyObject *(*flags_add)(PyObject *module,
-			   const char *typename,
+			   const char *typename_,
 			   const char *strip_prefix,
 			   GType gtype);
     PyObject* (*flags_from_gtype)(GType gtype, int value);
 
     gboolean threads_enabled;
     int       (*enable_threads) (void);
+    int       (*gil_state_ensure) (void);
+    void      (*gil_state_release) (int flag);
 };
 
 #ifndef _INSIDE_PYGOBJECT_
@@ -197,11 +217,13 @@ struct _PyGObject_Functions *_PyGObject_API;
   } G_STMT_END
 
 #define pyg_threads_enabled (_PyGObject_API->threads_enabled)
-#define pyg_gil_state_ensure() (_PyGObject_API->threads_enabled? (PyGILState_Ensure()) : 0)
+
+#define pyg_gil_state_ensure() (_PyGObject_API->threads_enabled? (_PyGObject_API->gil_state_ensure()) : 0)
 #define pyg_gil_state_release(state) G_STMT_START {     \
     if (_PyGObject_API->threads_enabled)                \
-        PyGILState_Release(state);                      \
+        _PyGObject_API->gil_state_release(state);       \
     } G_STMT_END
+
 #define pyg_begin_allow_threads                 \
     G_STMT_START {                              \
         PyThreadState *_save = NULL;            \
@@ -233,4 +255,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 
 #endif /* !_INSIDE_PYGOBJECT_ */
 
+G_END_DECLS
+
 #endif /* !_PYGOBJECT_H_ */
